@@ -8,11 +8,11 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.aws_iam
-import aws_cdk.core
-import constructs
+import aws_cdk.aws_iam._jsii
+import aws_cdk.core._jsii
+import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.42.1", __name__[0:-6], "aws-kms@1.42.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.43.0", __name__[0:-6], "aws-kms@1.43.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
